<?xml version="1.0" ?><!DOCTYPE TS><TS language="cs" version="2.1">
<context>
    <name>AboutDialog</name>
    <message>
        <source> About Boomaga</source>
        <translation> O programu Boomaga</translation>
    </message>
    <message>
        <source>About</source>
        <translation>O programu</translation>
    </message>
    <message>
        <source>Authors</source>
        <translation>Autoři</translation>
    </message>
    <message>
        <source>Thanks</source>
        <translation>Poděkování</translation>
    </message>
    <message>
        <source>Translations</source>
        <translation>Překlady</translation>
    </message>
    <message>
        <source>Version: %1</source>
        <translation>Verze: %1</translation>
    </message>
    <message>
        <source>Boomaga provides a virtual printer for CUPS. This can be used for print preview or for print booklets.</source>
        <translation>Boomaga poskytuje virtuální tiskárnu pro CUPS. To lze použít pro tisk náhledů nebo na tisk knížeček.</translation>
    </message>
    <message>
        <source>Copyright: %1-%2 %3</source>
        <translation>Autorské právo: %1-%2 %3</translation>
    </message>
    <message>
        <source>Homepage: %1</source>
        <translation>Stránky: %1</translation>
    </message>
    <message>
        <source>License: %1</source>
        <translation>Licence: %1</translation>
    </message>
    <message>
        <source>If you are interested in working with our development team, &lt;a %1&gt;join us&lt;/a&gt;.</source>
        <translation>Pokud byste měli zájem pracovat v naší vývojářské skupině, &lt;a %1&gt;připojte se k nám&lt;/a&gt;.</translation>
    </message>
    <message>
        <source>Special thanks to:</source>
        <translation>Zvláštní poděkování:</translation>
    </message>
    <message>
        <source>If you want to help translate, we will be glad to see you in our translation team on &lt;a %1&gt;Transifex server&lt;/a&gt;.</source>
        <translation>Pokud chcete pomoci s překladem, podívejte se na překladatelský tým na &lt;a %1&gt;Transifexu&lt;/a&gt;.</translation>
    </message>
    <message>
        <source>Boomaga is developed by the &lt;a %1&gt;Boomaga Team and contributors&lt;/a&gt; on GitHub.</source>
        <translation>Boomaga je vyvíjena &lt;a %1&gt;týmem Boomaga a přispěvateli&lt;/a&gt; na GitHub.</translation>
    </message>
</context>
<context>
    <name>BooFile</name>
    <message>
        <source>I can&apos;t write to file &apos;%1&apos;</source>
        <translation>Nelze zapisovat do souboru &apos;%1&apos;</translation>
    </message>
</context>
<context>
    <name>ConfigDialog</name>
    <message>
        <source>Preferences</source>
        <translation>Nastavení</translation>
    </message>
    <message>
        <source>Divide your long booklets into smaller sub-booklets for printing.</source>
        <translation>Rozdělit velké knížečky pro tisk na menší dílčí knížečky.</translation>
    </message>
    <message>
        <source>Print as sub-booklets</source>
        <translation>Rozdělit tisk knížeček (dílčí knížečky)</translation>
    </message>
    <message>
        <source>Maximum number of sheets in your sub-booklet.</source>
        <translation>Největší počet listů na dílčí knížečku.</translation>
    </message>
    <message>
        <source>Sheets per sub-booklet:</source>
        <translation>Listů na dílčí knížečku</translation>
    </message>
    <message>
        <source>Autosave your jobs every time you print.</source>
        <translation>Při tisku vždy automaticky uložit vaše úlohy.</translation>
    </message>
    <message>
        <source>AutoSave the recent sessions</source>
        <translation>Automaticky uložit nedávná sezení</translation>
    </message>
    <message>
        <source>Allow negative page margins:</source>
        <translation>Povolit záporné okraje stran:</translation>
    </message>
    <message>
        <source>Select directory for saved jobs.</source>
        <translation>Vybrat adresář pro uložené úlohy.</translation>
    </message>
    <message>
        <source>Directory for saved sessions:</source>
        <translation>Adresář pro uložená sezení:</translation>
    </message>
    <message>
        <source>Right-to-left direction</source>
        <translation>Směr zprava doleva</translation>
    </message>
</context>
<context>
    <name>CupsBooFile</name>
    <message>
        <source>I can&apos;t read file &quot;%1&quot; either because it&apos;s not a supported file type, or because the file has been damaged.</source>
        <translation>Nelze přečíst soubor &quot;%1&quot;, protože buď tento není podporovaným souborovým typem, nebo protože soubor byl poškozen.</translation>
    </message>
</context>
<context>
    <name>ExportToPdf</name>
    <message>
        <source>Print to PDF</source>
        <translation>Tisk do PDF</translation>
    </message>
    <message>
        <source>File name</source>
        <translation>Název souboru</translation>
    </message>
    <message>
        <source>Output file:</source>
        <translation>Výstupní soubor:</translation>
    </message>
    <message>
        <source>...</source>
        <translation>...</translation>
    </message>
    <message>
        <source>Meta info</source>
        <translation>Popisné informace</translation>
    </message>
    <message>
        <source>Author:</source>
        <translation>Autor:</translation>
    </message>
    <message>
        <source> The name of the person who created the document.</source>
        <translation>Jméno osoby, která dokument vytvořila.</translation>
    </message>
    <message>
        <source>Title:</source>
        <translation>Název:</translation>
    </message>
    <message>
        <source>Subject:</source>
        <translation>Předmět:</translation>
    </message>
    <message>
        <source> The subject of the document.</source>
        <translation>Předmět dokumentu.</translation>
    </message>
    <message>
        <source> Keywords associated with the document.</source>
        <translation>Klíčová slova spojená s dokumentem.</translation>
    </message>
    <message>
        <source>Keywords:</source>
        <translation>Klíčová slova:</translation>
    </message>
    <message>
        <source>PDF files (*.pdf);;All files (*.*)</source>
        <translation>Soubory PDF (*.pdf);;Všechny soubory (*.*)</translation>
    </message>
    <message>
        <source>Overwrite file?</source>
        <translation>Přepsat soubor?</translation>
    </message>
    <message>
        <source>A file named &quot;%1&quot; already exists.
Are you sure you want to overwrite it?</source>
        <translation>Soubor s názvem &quot;%1&quot; již existuje.
Jste si jistý, že jej chcete přepsat?</translation>
    </message>
    <message>
        <source> The document&apos;s title.</source>
        <translation>Název dokumentu.</translation>
    </message>
</context>
<context>
    <name>InFile</name>
    <message>
        <source>I can&apos;t read file &quot;%1&quot; either because it&apos;s not a supported file type, or because the file has been damaged.</source>
        <translation>Nelze přečíst soubor &quot;%1&quot;, protože buď tento není podporovaným souborovým typem, nebo protože soubor byl poškozen.</translation>
    </message>
</context>
<context>
    <name>JobListView</name>
    <message>
        <source>%1 pages</source>
        <translation>%1 stran</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <source>&amp;File</source>
        <translation>&amp;Soubor</translation>
    </message>
    <message>
        <source>&amp;Preferences</source>
        <translation>&amp;Nastavení</translation>
    </message>
    <message>
        <source>Help</source>
        <translation>Nápověda</translation>
    </message>
    <message>
        <source>Layout</source>
        <translation>Rozvržení</translation>
    </message>
    <message>
        <source>1 up</source>
        <translation>1 strana na list</translation>
    </message>
    <message>
        <source>2 up</source>
        <translation>2 strany na list</translation>
    </message>
    <message>
        <source>Booklet</source>
        <translation>Knížečka</translation>
    </message>
    <message>
        <source>Print on both sides of a sheet.</source>
        <comment>MainForm::Double-sided checkbox tooltip</comment>
        <translation>Tisknout na obě strany listu.</translation>
    </message>
    <message>
        <source>Double-sided</source>
        <comment>MainForm::Double-sided checkbox</comment>
        <translation>Oboustranný</translation>
    </message>
    <message>
        <source>Jobs</source>
        <translation>Úlohy</translation>
    </message>
    <message>
        <source>Printer</source>
        <translation>Tiskárna</translation>
    </message>
    <message>
        <source>Configure...</source>
        <translation>Nastavit...</translation>
    </message>
    <message>
        <source>Toolbar</source>
        <translation>Nástrojový pruh</translation>
    </message>
    <message>
        <source>&amp;Print</source>
        <translation>&amp;Tisk</translation>
    </message>
    <message>
        <source>E&amp;xit</source>
        <translation>&amp;Ukončit</translation>
    </message>
    <message>
        <source>Print and Close</source>
        <translation>Vytisknout a zavřít</translation>
    </message>
    <message>
        <source>Ctrl+P</source>
        <translation>Ctrl+P</translation>
    </message>
    <message>
        <source>Next sheet</source>
        <translation>Další list</translation>
    </message>
    <message>
        <source>Previous sheet</source>
        <translation>Předchozí list</translation>
    </message>
    <message>
        <source>About Boomaga</source>
        <translation>O programu Boomaga</translation>
    </message>
    <message>
        <source>Boomaga</source>
        <translation>Boomaga</translation>
    </message>
    <message>
        <source>%v of %m</source>
        <comment>Format for QProgressBar (http://qt-project.org/doc/qt-4.8/qprogressbar.html#format-prop)</comment>
        <translation>%v z %m</translation>
    </message>
    <message>
        <source>Print the all pages on %1.</source>
        <translation>Tisk všech stran na %1.</translation>
    </message>
    <message>
        <source>Print the odd pages on %1.&lt;p&gt;When finished, turn the pages, insert them into the printer&lt;br&gt;and click the Continue button.</source>
        <translation>Tisk lichých stran na %1.&lt;p&gt;Až bude dokončeno, obraťte strany, vložte je do tiskárny&lt;br&gt;a klepněte na tlačítko Pokračovat.</translation>
    </message>
    <message>
        <source>Print the even pages on %1.</source>
        <translation>Tisk sudých stran na %1.</translation>
    </message>
    <message>
        <source>Continue</source>
        <translation>Pokračovat</translation>
    </message>
    <message>
        <source>%1 pages</source>
        <comment>Status bar</comment>
        <translation>%1 stran</translation>
    </message>
    <message>
        <source>%1 page</source>
        <comment>Status bar</comment>
        <translation>%1 strana</translation>
    </message>
    <message>
        <source>%1 sheets</source>
        <comment>Status bar</comment>
        <translation>%1 listů</translation>
    </message>
    <message>
        <source>%1 sheet</source>
        <comment>Status bar</comment>
        <translation>%1 list</translation>
    </message>
    <message>
        <source>Sheet %1 of %2</source>
        <comment>Status bar</comment>
        <translation>List %1 z %2</translation>
    </message>
    <message>
        <source>Insert blank page after this page</source>
        <translation>Vložit prázdnou stranu po této straně</translation>
    </message>
    <message>
        <source>Delete this page</source>
        <translation>Smazat tuto stranu</translation>
    </message>
    <message>
        <source>Undo delete</source>
        <translation>Zpět krok smazání</translation>
    </message>
    <message>
        <source>Insert blank page before this page</source>
        <translation>Vložit prázdnou stranu před tuto stranu</translation>
    </message>
    <message>
        <source>Save</source>
        <translation>Uložit</translation>
    </message>
    <message>
        <source>Save project</source>
        <translation>Uložit projekt</translation>
    </message>
    <message>
        <source>Ctrl+S</source>
        <translation>Ctrl+S</translation>
    </message>
    <message>
        <source>Save as...</source>
        <translation>Uložit jako...</translation>
    </message>
    <message>
        <source>Save project under a new name</source>
        <translation>Uložit projekt pod novým názvem</translation>
    </message>
    <message>
        <source>Ctrl+Shift+S</source>
        <translation>Ctrl+Shift+S</translation>
    </message>
    <message>
        <source>Open...</source>
        <translation>Otevřít...</translation>
    </message>
    <message>
        <source>Open an existing project</source>
        <translation>Otevřít stávající projekt</translation>
    </message>
    <message>
        <source>Ctrl+O</source>
        <translation>Ctrl+O</translation>
    </message>
    <message>
        <source>Page %1</source>
        <comment>'Undo deletion' menu item</comment>
        <translation>Strana %1</translation>
    </message>
    <message>
        <source>Boomaga files (*.boo);;All files (*.*)</source>
        <translation>Soubory Boomaga (*.boo);;Všechny soubory (*.*)</translation>
    </message>
    <message>
        <source>Project saved successfully.</source>
        <translation>Projekt byl úspěšně uložen.</translation>
    </message>
    <message>
        <source>All supported files (*.pdf *.boo);;Boomaga files (*.boo);;PDF files (*.pdf);;All files (*.*)</source>
        <translation>Všechny podporované soubory (*.pdf *.boo);;Soubory Boomaga (*.boo);;Soubory PDF (*.pdf);;Všechny soubory (*.*)</translation>
    </message>
    <message>
        <source>4 up horizontal</source>
        <translation>4 listy na stranu (formát na šířku)</translation>
    </message>
    <message>
        <source>4 up vertical</source>
        <translation>4 listy na stranu (formát na výšku)</translation>
    </message>
    <message>
        <source>8 up horizontal</source>
        <translation>8 listů na stranu (formát na šířku)</translation>
    </message>
    <message>
        <source>8 up vertical</source>
        <translation>8 listů na stranu (formát na výšku)</translation>
    </message>
    <message>
        <source>Start new booklet from this page</source>
        <translation>Začít novou knížečku od této strany</translation>
    </message>
    <message>
        <source>Don&apos;t start new booklet from this page</source>
        <translation>Nezačínat novou knížečku od této strany</translation>
    </message>
    <message>
        <source>Rotate page to the left</source>
        <translation>Otočit stranu doleva</translation>
    </message>
    <message>
        <source>Rotate page to the right</source>
        <translation>Otočit stranu doprava</translation>
    </message>
    <message>
        <source>Rename job</source>
        <translation>Přejmenovat tiskovou úlohu</translation>
    </message>
    <message>
        <source>Rotate job to the left</source>
        <translation>Otočit tiskovou úlohu doleva</translation>
    </message>
    <message>
        <source>Rotate job to the right</source>
        <translation>Otočit tiskovou úlohu doprava</translation>
    </message>
    <message>
        <source>Job title:</source>
        <translation>Název tiskové úlohy:</translation>
    </message>
    <message>
        <source>Export the project to PDF</source>
        <translation>Vyvést projekt do PDF</translation>
    </message>
    <message>
        <source>Ctrl+E</source>
        <translation>Ctrl+E</translation>
    </message>
    <message>
        <source>Clone job...</source>
        <translation>Klonovat úlohu...</translation>
    </message>
    <message>
        <source>Clone job</source>
        <translation>Klonovat úlohu</translation>
    </message>
    <message>
        <source>Number of copies:</source>
        <translation>Počet kopií:</translation>
    </message>
    <message>
        <source>Print with options...</source>
        <translation>Tisknout s volbami...</translation>
    </message>
    <message>
        <source>Select number of copies before printing.</source>
        <translation>Vybrat před tiskem počet kopií.</translation>
    </message>
    <message>
        <source>Ctrl+Shift+P</source>
        <translation>Ctrl+Shift+P</translation>
    </message>
    <message>
        <source>Sub-booklets</source>
        <translation>Dílčí knížečky</translation>
    </message>
    <message>
        <source>Undo delete page</source>
        <translation>Zpět smazání strany</translation>
    </message>
    <message>
        <source>Page %1 of %2</source>
        <comment>Status bar</comment>
        <translation>Strana %1 z %2</translation>
    </message>
    <message>
        <source>Recent files</source>
        <translation>Nedávné soubory</translation>
    </message>
    <message>
        <source>&amp;Edit page</source>
        <translation>&amp;Upravit stranu</translation>
    </message>
    <message>
        <source>Edit &amp;job</source>
        <translation>Upravit úl&amp;ohu</translation>
    </message>
    <message>
        <source>&amp;Export to PDF...</source>
        <translation>&amp;Vyvést do PDF...</translation>
    </message>
    <message>
        <source>Delete pages until the end of the job</source>
        <translation>Odstranit strany až po konec úlohy</translation>
    </message>
    <message>
        <source>Delete current job</source>
        <translation>Smazat nynější úlohu</translation>
    </message>
    <message>
        <source>Auto saving</source>
        <translation>Automatické ukládání</translation>
    </message>
    <message>
        <source>I can&apos;t create directory &quot;%1&quot;</source>
        <translation>Nelze vytvořit adresář &quot;%1&quot;</translation>
    </message>
    <message>
        <source>%1 %2: Page %3</source>
        <comment>'Undo deletion' menu item, (%1 - is a job number, %2 - is a job title, %3 - is a page number in this job</comment>
        <translation>%1 %2: Strana %3</translation>
    </message>
</context>
<context>
    <name>PostScriptFile</name>
    <message>
        <source>Converting PostScript to PDF</source>
        <comment>Progressbar text</comment>
        <translation>Převést PostScript do PDF</translation>
    </message>
    <message>
        <source>I can&apos;t start gs converter: &quot;%1&quot;</source>
        <comment>Error message. 'gs' is a command line tool from ghostscript</comment>
        <translation>Nelze spustit převaděč gs: &quot;%1&quot;</translation>
    </message>
</context>
<context>
    <name>PrintDialog</name>
    <message>
        <source>Print document</source>
        <translation>Vytisknout dokument</translation>
    </message>
    <message>
        <source>Number of copies:</source>
        <translation>Počet kopií:</translation>
    </message>
    <message>
        <source>Collate copies:</source>
        <translation>Srovnat kopie:</translation>
    </message>
</context>
<context>
    <name>PrinterSettings</name>
    <message>
        <source>Margins (mm)</source>
        <translation>Okraje (mm)</translation>
    </message>
    <message>
        <source>Right:</source>
        <translation>Vpravo:</translation>
    </message>
    <message>
        <source>Bottom:</source>
        <translation>Dole:</translation>
    </message>
    <message>
        <source>Internal:</source>
        <translation>Vnitřní:</translation>
    </message>
    <message>
        <source>Left:</source>
        <translation>Vlevo:</translation>
    </message>
    <message>
        <source>Top:</source>
        <translation>Nahoře:</translation>
    </message>
    <message>
        <source>Draw border</source>
        <translation>Kreslit okraj</translation>
    </message>
    <message>
        <source>Print in reverse order</source>
        <translation>Tisknout v obráceném pořadí</translation>
    </message>
    <message>
        <source>Printer has duplexer</source>
        <translation>Tiskárna je pravá-levá stránka</translation>
    </message>
    <message>
        <source>Manual with reverse (suitable for most printers)</source>
        <translation>Ruční s obráceným (vhodné pro většinu tiskáren)</translation>
    </message>
    <message>
        <source>Manual without reverse</source>
        <translation>Ruční bez obráceného</translation>
    </message>
    <message>
        <source>Preferences of &quot;%1&quot;</source>
        <translation>Nastavení &quot;%1&quot;</translation>
    </message>
    <message>
        <source>Profiles</source>
        <translation>Profily</translation>
    </message>
    <message>
        <source>+</source>
        <translation>+</translation>
    </message>
    <message>
        <source>-</source>
        <translation>-</translation>
    </message>
    <message>
        <source>Reset to default</source>
        <translation>Obnovit výchozí nastavení</translation>
    </message>
    <message>
        <source>Profile %1</source>
        <comment>Defaul name for created printer profile in the Printer Settings diaog</comment>
        <translation>Profil %1</translation>
    </message>
    <message>
        <source>Color mode:</source>
        <translation>Barevný režim:</translation>
    </message>
    <message>
        <source>Default</source>
        <translation>Výchozí</translation>
    </message>
    <message>
        <source>Force grayscale</source>
        <translation>Vynutit odstíny šedi</translation>
    </message>
    <message>
        <source>Force color</source>
        <translation>Vynutit barvu</translation>
    </message>
    <message>
        <source>Settings</source>
        <translation>Nastavení</translation>
    </message>
    <message>
        <source>Print on both sides</source>
        <translation>Tisknout na obě strany</translation>
    </message>
    <message>
        <source>Flip on short edge</source>
        <translation>Převrátit na krátkém okraji</translation>
    </message>
    <message>
        <source>Flip on long edge</source>
        <translation>Převrátit na dlouhém okraji</translation>
    </message>
</context>
<context>
    <name>Project</name>
    <message>
        <source>Boomaga</source>
        <comment>Error message title</comment>
        <translation>Boomaga</translation>
    </message>
    <message>
        <source>I can&apos;t write to file &apos;%1&apos;</source>
        <translation>Nelze zapisovat do souboru &apos;%1&apos;</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <source>I can&apos;t read from file &apos;%1&apos;</source>
        <translation>Nelze číst ze souboru &apos;%1&apos;</translation>
    </message>
    <message>
        <source>I can&apos;t write to file &apos;%1&apos;</source>
        <translation>Nelze zapisovat do souboru &apos;%1&apos;</translation>
    </message>
    <message>
        <source>Untitled</source>
        <translation>Bez názvu</translation>
    </message>
    <message>
        <source>Default</source>
        <comment>Printer profile default name</comment>
        <translation>Výchozí</translation>
    </message>
    <message>
        <source>I can&apos;t open file &quot;%1&quot; (Empty file name)</source>
        <comment>Error message. %1 is a file name</comment>
        <translation>Nelze otevřít soubor &quot;%1&quot; (prázdný název souboru)</translation>
    </message>
    <message>
        <source>I can&apos;t open file &quot;%1&quot; (No such file or directory)</source>
        <comment>Error message. %1 is a file name</comment>
        <translation>Nelze otevřít soubor &quot;%1&quot; (žádný takový soubor nebo adresář)</translation>
    </message>
    <message>
        <source>I can&apos;t open file &quot;%1&quot; (Access denied)</source>
        <comment>Error message. %1 is a file name</comment>
        <translation>Nelze otevřít soubor &quot;%1&quot; (přístup odepřen)</translation>
    </message>
    <message>
        <source>I can&apos;t open file &quot;%1&quot;</source>
        <comment>Error message. %1 is a file name</comment>
        <translation>Nelze otevřít soubor &quot;%1&quot;</translation>
    </message>
</context>
<context>
    <name>Settings</name>
    <message>
        <source>~/Untitled.pdf</source>
        <translation>~/Nepojmenovaný.pdf</translation>
    </message>
</context>
<context>
    <name>SubBookletView</name>
    <message>
        <source>Sub-booklet %1</source>
        <translation>Dílčí knížečka %1</translation>
    </message>
    <message>
        <source>%1 pages</source>
        <translation>%1 stran</translation>
    </message>
</context>
<context>
    <name>TmpPdfFile</name>
    <message>
        <source>I can&apos;t create temporary file &quot;%1&quot;</source>
        <translation>Nelze vytvořit dočasný soubor &quot;%1&quot;</translation>
    </message>
    <message>
        <source>I can&apos;t read file &apos;%1&apos;</source>
        <translation>Nelze přečíst soubor &apos;%1&apos;</translation>
    </message>
    <message>
        <source>I can&apos;t write to file &apos;%1&apos;</source>
        <translation>Nelze zapisovat do souboru &apos;%1&apos;</translation>
    </message>
    <message>
        <source>I can&apos;t write file &quot;%1&quot;</source>
        <translation>Nelze zapsat soubor &quot;%1&quot;</translation>
    </message>
</context>
</TS>